@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id$
  *
- *    Copyright (c) 2004-2018 by P. Wessel and Michael Chandler
+ *    Copyright (c) 2004-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html) and Michael Chandler
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -23,7 +22,8 @@
 #include "gmt_dev.h"
 #include "mgd77.h"
 
-#define THIS_MODULE_NAME	"mgd77header"
+#define THIS_MODULE_CLASSIC_NAME	"mgd77header"
+#define THIS_MODULE_MODERN_NAME	"mgd77header"
 #define THIS_MODULE_LIB		"mgd77"
 #define THIS_MODULE_PURPOSE	"Create MGD77 headers from A77 files"
 #define THIS_MODULE_KEYS	""
@@ -71,9 +71,9 @@ GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *C) {	/*
 GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	struct MGD77_CONTROL M;
 
-	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
-	GMT_Message (API, GMT_TIME_NONE, "usage: mgd77info <cruise(s)>  [-H<headinfo>] [-Mf[<item>]|r|e|h] [%s]\n\n", GMT_V_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "usage: %s <cruise(s)>  [-H<headinfo>] [-Mf[<item>]|r|e|h] [%s] [%s]\n\n", name, GMT_V_OPT, GMT_PAR_OPT);
         
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
              
@@ -194,12 +194,11 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if ((error = gmt_report_usage (API, options, 0, usage)) != GMT_NOERROR) bailout (error);	/* Give usage if requested */
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	MGD77_Init (GMT, &M);		/* Initialize input MGD77 Machinery */
@@ -212,7 +211,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	tod = localtime (&tt);
 	if (Ctrl->H.active) {
 		if ((fp = gmt_fopen (GMT, Ctrl->H.file, "r")) == NULL) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Error: Cannot open header items input file (%s)\n", Ctrl->H.file);
+			GMT_Report (API, GMT_MSG_NORMAL, "Cannot open header items input file (%s)\n", Ctrl->H.file);
 			Return (GMT_NO_INPUT);
 		}
 	}
@@ -224,14 +223,14 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	n_paths = MGD77_Path_Expand (GMT, &M, options, &list);	/* Get list of requested IDs */
 
 	if (n_paths <= 0) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Error: No cruises given\n");
+		GMT_Report (API, GMT_MSG_NORMAL, "No cruises given\n");
 		if (fp) gmt_fclose (GMT, fp);
 		Return (GMT_NO_INPUT);
 	}
 
 	saved_range = GMT->current.io.geo.range;	/* We may have to reset thisso keep a copy */
 	gmt_set_geographic (GMT, GMT_OUT);	/* Output lon/lat */
-	GMT->current.io.col_type[GMT_OUT][2] = M.time_format;
+	gmt_set_column (GMT, GMT_OUT, GMT_Z, M.time_format);
 
 	use = (M.original || M.format != MGD77_FORMAT_CDF) ? MGD77_ORIG : MGD77_REVISED;
 
@@ -239,7 +238,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 
 		if (MGD77_Open_File (GMT, list[argno], &M, MGD77_READ_MODE)) continue;
 
-		GMT_Report (API, GMT_MSG_VERBOSE, "Now processing cruise %s\n", list[argno]);
+		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Now processing cruise %s\n", list[argno]);
 
 		D = MGD77_Create_Dataset (GMT);
 
@@ -420,12 +419,12 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 						if (teny >= 9)
 							tquad = 7;
 					}
-					if (teny > 8) sprintf (value,"%s%.1d%01.0f%02.0f,",value,tquad,fabs(teny-9.0),fabs(tenx-18.0));
-					else sprintf (value,"%s%.1d%01.0f%02.0f,",value,tquad,fabs(teny-8.0),fabs(tenx-18.0));
+					if (teny > 8) snprintf (value, BUFSIZ, "%s%.1d%01.0f%02.0f,",value,tquad,fabs(teny-9.0),fabs(tenx-18.0));
+					else snprintf (value, BUFSIZ, "%s%.1d%01.0f%02.0f,",value,tquad,fabs(teny-8.0),fabs(tenx-18.0));
 				}
 			}
 		}
-		sprintf (value, "%s9999", value); i++;
+		snprintf (value, BUFSIZ, "%s9999", value); i++;
 		while (i < 30) { /* MGD77 format can store up to this many 10x10 identifiers */
  			sprintf (value,"%s,   0",value);
 			i++;
